--[[
	The entry point of the addon.
	
	Copyright (C) Udorn (Blackhand)
	
	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.	
--]]

vendor.Vendor = AceLibrary("AceAddon-2.0"):new("AceConsole-2.0", "AceHook-2.1", "AceEvent-2.0", "AceModuleCore-2.0", "AceDebug-2.0", "AceDB-2.0");
local L = vendor.Locale.GetInstance()
local waterFall = AceLibrary("Waterfall-1.0");

local self = vendor.Vendor;

--[[
	Sets the given new value for the specified field.
--]]
local function _SetValue(field, value)
	self.db.profile[field] = value;
	self:ApplySettings();
end

--[[
	Returns the current value for the specified field.
--]]
local function _GetValue(field)
	return self.db.profile[field];	
end

--[[
	Applies settings locally, without calling the modules.
--]]
local function _ApplySettings()
	-- apply settings locally	
	self:SetDebugging(self.db.profile.debug);
end

--[[
	All options of the addon.
--]]
local function _CreateOptions(self)
	self.options = { 
    type = "group",
	name = L["AuctionMaster"],
	desc = L["AuctionMaster"],
    args = {
		conf = {
			type = "execute",
			name = L["Configuration"],
			desc = L["Opens a configuration window."],
			func = function()
				if (waterFall:IsOpen("AuctionMaster")) then 
					waterFall:Close("AuctionMaster"); 
				else
					waterFall:Open("AuctionMaster");
				end				 
			end
		},
		submit = {
			type = "execute",
			name = L["Submit"],
			desc = L["Describes how to submit the AuctionMaster database file."],
			func = function()
				-- obfuscated email
				self:Print(L["Please send the AuctionMaster.lua database file to %s. You can find it in the \"WTF\\Account\\<account-name>\\SavedVariables\" directory located in your WoW installation. It contains no personal information. The file is written after exiting WoW, so please don't send it while playing WoW."]:format("auc".."master".."@".."goo".."glemail.com"));
			end
		},
		deny_submit = {
			type = "execute",
			name = L["Deny submit"],
			desc = L["Deactivates the sell price reminder for this release."],
			func = function()
				self.db.profile.denySubmit = self.version
				self:Print(L["Sell price submit reminder has been deactivated for this release."]);
			end
		},
    },
	}
end

--[[
	Handles the disabling of the debugger.
--]]
local function _OnDebugDisable()
	self.db.profile.debug = false;
end

--[[
	Handles the enabling of the debugger.
--]]
local function _OnDebugEnable()
	self.db.profile.debug = true;
end

--[[
	Initializes the addon.
--]]
function vendor.Vendor:OnInitialize()
	self.version = GetAddOnMetadata("AuctionMaster", "Version")
	self:RegisterDB("VendorDb");
	self:RegisterDefaults("profile", {
		useTooltips = true,
	});
	self:RegisterDefaults("account", {
		locale = "unknown",
		checksum = "",
		hasChargesPattern = false,
	});	
	self.OnDebugEnable = _OnDebugEnable; -- to be able to remember the debug state
	self.OnDebugDisable = _OnDebugDisable;
	_CreateOptions(self);
	waterFall:Register("AuctionMaster", "aceOptions", self.options,
						"title", "AuctionMaster",
						"treeLevels", 3,
						"colorR", 1, "colorG", 0.3, "colorB", 0.3);
	self:RegisterChatCommand({"/am"}, self.options);
	
	-- init Blizzard_AuctionUi
	if (not IsAddOnLoaded("Blizzard_AuctionUi")) then
		local loaded, reason = LoadAddOn("Blizzard_AuctionUi")
		if (not loaded) then
			if (reason) then
				vendor.Vendor:Error("Blizzard_AuctionUi not loaded because of: "..reason)
			else
				vendor.Vendor:Error("Blizzard_AuctionUi not loaded because of unknown reason")
			end
		end
	end
end

--[[
	Enables the addon.
--]]
function vendor.Vendor:OnEnable()
	self:ApplySettings();	
	DisableAddOn("Vendor");-- just in case, if somebody has the old addon installed
	-- remember the locale used
	self.db.account.locale = GetLocale()
end

--[[
	Enables a profile.
--]]
function vendor.Vendor:OnProfileEnable()
	self:ApplySettings();
end

--[[
	Displays the given error message
--]]
function vendor.Vendor:Error(msg)
	self:CustomPrint(1, 0, 0, nil, nil, " ", msg)
end

--[[
	Calls ApplySettings for all modules.
--]]
function vendor.Vendor:ApplySettings()
	_ApplySettings();
	-- apply settings for all modules
	for name, module in self:IterateModules() do
		if module.ApplySettings then
			module:ApplySettings();
		end
	end
end

function vendor.Vendor:TestPaper()
	vendor.Vendor:Debug("TestPaper enter")
	local frame1 = CreateFrame("Frame", nil, UIParent)
	frame1:SetPoint("CENTER")
	frame1:SetWidth(64)
	frame1:SetHeight(64)
	frame1:SetToplevel(true)
	local texture1 = frame1:CreateTexture(nil, "OVERLAY")
	texture1:SetWidth(64)
	texture1:SetHeight(64)
	texture1:SetTexCoord(0, 1, 0, 1)
	texture1:SetPoint("TOPLEFT", 0, 0)
	texture1:SetTexture("Interface\\Addons\\AuctionMaster\\Media\\am_logo")
	
	local frame2 = CreateFrame("Frame", nil, UIParent)
	frame2:SetPoint("TOPLEFT", frame1, "TOPRIGHT", 0, 0)
	frame2:SetWidth(64)
	frame2:SetHeight(64)
	frame2:SetToplevel(true)
	local texture2 = frame2:CreateTexture(nil, "OVERLAY")
	texture2:SetWidth(64)
	texture2:SetHeight(64)
	texture2:SetTexCoord(0, 1, 0, 1)
	texture2:SetPoint("TOPLEFT", 0, 0)
	SetPortraitToTexture(texture2, "Interface\\Addons\\AuctionMaster\\Media\\am_logo")

	local frame3 = CreateFrame("Frame", nil, UIParent)
	frame3:SetPoint("TOPLEFT", frame2, "TOPRIGHT", 0, 0)
	frame3:SetWidth(64)
	frame3:SetHeight(64)
	frame3:SetToplevel(true)
	local texture3 = frame3:CreateTexture(nil, "OVERLAY")
	texture3:SetWidth(64)
	texture3:SetHeight(64)
	texture3:SetTexCoord(0, 1, 0, 1)
	texture3:SetPoint("TOPLEFT", 0, 0)
	SetPortraitToTexture(texture3, "Interface\\ContainerFrame\\KeyRing-Bag-Icon")
	
	
	vendor.Vendor:Debug("TestPaper exit")
end
